@@ -199,6 +199,18 @@ if (require("testthat") && require("effectsize")) {
     expect_error(interpret_pnfi(0.6, "DUPA"))
     expect_error(interpret_rmsea(0.6, "DUPA"))
     expect_error(interpret_srmr(0.6, "DUPA"))
+
+    skip_on_cran()
+    skip_if_not_installed("lavaan")
+    skip_if_not_installed("performance", minimum_version = "0.8.0.1")
+
+    structure <- " ind60 =~ x1 + x2 + x3
+                   dem60 =~ y1 + y2 + y3
+                   dem60 ~ ind60 "
+    model <- lavaan::sem(structure, data = lavaan::PoliticalDemocracy)
+    int <- interpret(model)
+    expect_equal(int$Name, c("GFI", "AGFI", "NFI", "NNFI", "CFI", "RMSEA", "SRMR", "RFI", "IFI", "PNFI"))
+    expect_equal(int$Value,c(0.9666, 0.9124, 0.9749, 1.0001, 1, 0, 0.0273, 0.9529, 1.0001, 0.5199), tolerance = 0.001)
   })
 
   test_that("interpret_icc", {
@@ -207,7 +219,13 @@ if (require("testthat") && require("effectsize")) {
     expect_error(interpret_icc(0.6, "DUPA"))
   })
 
-  test_that("interpret_pf", {
+  test_that("interpret_vif", {
+    expect_equal(interpret_vif(c(1, 5.5, 10)), c("low", "moderate", "high"), ignore_attr = TRUE)
+    expect_equal(interpret_icc(0.6, rules(c(0.5), c("A", "B")))[1], "B")
+    expect_error(interpret_icc(0.6, "DUPA"))
+  })
+
+  test_that("interpret_pd", {
     expect_equal(interpret_pd(c(0.9, 0.99)), c("not significant", "significant"), ignore_attr = TRUE)
     expect_equal(interpret_pd(c(0.9, 0.99), "makowski2019"), c("uncertain", "likely existing"), ignore_attr = TRUE)
     expect_equal(interpret_pd(0.6, rules(c(0.5), c("A", "B")))[1], "B")
